@@ -35,3 +35,10 @@ class SElement:
         matrix[:3, :3] = rot_matrix
         matrix[:3, 3] = translation
         return cls.from_matrix(matrix)
+
+
+def to_pos_matrix(selement: SElement) -> list:
+    pos_matrix = []
+    pos_matrix.extend(selement.translation.tolist())
+    pos_matrix.extend(selement.euler_rot(seq="zyx").tolist())
+    return pos_matrix
